@@ -80,20 +80,15 @@ optionsParser =
 main :: IO ()
 main = do
   opts <- parseOptions
+  prettyPrint opts $ expandTemplateDoc opts.variables opts.template
 
-  let expanded = expandTemplate opts.variables opts.template
-
-  if opts.noPretty
-    then T.putStrLn expanded
-    else prettyPrint opts expanded
-
-prettyPrint :: Options -> Text -> IO ()
+prettyPrint :: Options -> Doc Template.Ann -> IO ()
 prettyPrint opts expanded = do
   tty <- hIsTerminalDevice stdout
 
   let
     render =
-      if tty
+      if tty && not opts.noPretty
         then Ansi.renderStrict
         else Text.renderStrict
 
@@ -117,7 +112,7 @@ prettyPrint opts expanded = do
           $ reAnnotate AnnTemplate
           $ templatePretty opts.template
       , ""
-      , sectionPretty "Expanded" $ pretty expanded
+      , sectionPretty "Expanded" $ reAnnotate AnnTemplate expanded
       ]
 
 sectionPretty :: Text -> Doc Ann -> Doc Ann
@@ -137,6 +132,8 @@ annToAnsi = \case
   AnnTemplate x -> case x of
     AnnPunctuation -> Ansi.bold
     AnnOperator -> Ansi.color Ansi.Magenta
+    AnnIntercalate -> Ansi.color Ansi.Magenta
     AnnVarName -> Ansi.colorDull Ansi.Cyan
+    AnnVarValue -> Ansi.colorDull Ansi.Green
     AnnModifier -> Ansi.colorDull Ansi.Green
     AnnString -> Ansi.italicized <> Ansi.colorDull Ansi.Green
