@@ -8,20 +8,25 @@
 -- Portability : POSIX
 module Network.URI.Template.Expand
   ( expandTemplate
+  , expandTemplateDoc
   ) where
 
 import Prelude
 
 import Data.Map.Strict (Map)
-import Data.Text (Text)
+import Data.Text (Text, pack)
 import Network.URI.Template.Internal
+import Network.URI.Template.Internal.Pretty (Ann, Doc, pretty, renderPlain)
 import Network.URI.Template.VarName
 import Network.URI.Template.VarValue
 
 expandTemplate :: Map VarName VarValue -> Template -> Text
-expandTemplate env = foldMap (expandTemplatePart env) . (.unwrap)
+expandTemplate env = pack . renderPlain . expandTemplateDoc env
 
-expandTemplatePart :: Map VarName VarValue -> TemplatePart -> Text
+expandTemplateDoc :: Map VarName VarValue -> Template -> Doc Ann
+expandTemplateDoc env = foldMap (expandTemplatePart env) . (.unwrap)
+
+expandTemplatePart :: Map VarName VarValue -> TemplatePart -> Doc Ann
 expandTemplatePart env = \case
-  Lit t -> t
+  Lit t -> pretty t
   Exp e -> expandExpression env e
