@@ -22,7 +22,9 @@ import Prettyprinter.Render.String
 data Ann
   = AnnPunctuation
   | AnnOperator
+  | AnnIntercalate
   | AnnVarName
+  | AnnVarValue
   | AnnModifier
   | AnnString
 
